AnnotationManager class
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createCircleAnnotationManager(
{String? id, String? below}) → Future< CircleAnnotationManager> -
Create a CircleAnnotationManager to add/remove/update
CircleAnnotations on the map. -
createPointAnnotationManager(
{String? id, String? below}) → Future< PointAnnotationManager> -
Create a PointAnnotationManager to add/remove/update
PointAnnotations on the map. -
createPolygonAnnotationManager(
{String? id, String? below}) → Future< PolygonAnnotationManager> -
Create a PolygonAnnotationManager to add/remove/update
PolygonAnnotations on the map. -
createPolylineAnnotationManager(
{String? id, String? below}) → Future< PolylineAnnotationManager> -
Create a PolylineAnnotationManager to add/remove/update
PolylineAnnotations on the map. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
removeAnnotationManager(
BaseAnnotationManagerPlatformInterface manager) → Future< void> - Remove an AnnotationManager and all the annotations created by it.
-
removeAnnotationManagerById(
String id) → Future< void> -
Remove an AnnotationManager with the specified
idand all the annotation created by it. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited