addStyleModel method

  1. @override
Future<void> addStyleModel(
  1. String modelId,
  2. String modelUri
)

Adds a model to be used in the style. This API can also be used for updating a model. If the model for a given modelId was already added, it gets replaced by the new model.

The model can be used in model-id property in model layer.

@param modelId An identifier of the model. @param modelUri A URI for the model.

@return A string describing an error if the operation was not successful, empty otherwise.

Implementation

@override
Future<void> addStyleModel(String modelId, String modelUri) async {
  final String pigeonVar_channelName =
      'dev.flutter.pigeon.mapbox_maps_flutter.StyleManager.addStyleModel$pigeonVar_messageChannelSuffix';
  final BasicMessageChannel<Object?> pigeonVar_channel =
      BasicMessageChannel<Object?>(
        pigeonVar_channelName,
        pigeonChannelCodec,
        binaryMessenger: pigeonVar_binaryMessenger,
      );
  final Future<Object?> pigeonVar_sendFuture = pigeonVar_channel.send(
    <Object?>[modelId, modelUri],
  );
  final List<Object?>? pigeonVar_replyList =
      await pigeonVar_sendFuture as List<Object?>?;
  if (pigeonVar_replyList == null) {
    throw _createConnectionError(pigeonVar_channelName);
  } else if (pigeonVar_replyList.length > 1) {
    throw PlatformException(
      code: pigeonVar_replyList[0]! as String,
      message: pigeonVar_replyList[1] as String?,
      details: pigeonVar_replyList[2],
    );
  } else {
    return;
  }
}