mapbox_maps_flutter_mobile library

Classes

AnnotationManager
AttributionSettingsInterface
Shows the attribution icon on the map.
BaseAnnotationManager
The super class for all AnnotationManagers.
CircleAnnotationManager
The CircleAnnotationManager to add/update/delete CircleAnnotationAnnotations on the map.
CircleAnnotationMessenger_PigeonCodec
CompassSettingsInterface
Shows the compass on the map.
GestureListener
GestureListeners_PigeonCodec
GesturesController
Pairs the pigeon-generated GesturesSettingsInterface (settings host API) with the four gesture-event broadcast streams produced by the MapEventChannel event channels.
GesturesSettingsInterface
Gesture configuration allows to control the user touch interaction.
IndoorSelectorSettingsInterface
Settings for the indoor floor selector.
LocationSettings
Shows a location puck on the map.
LogBackend_PigeonCodec
LogConfiguration
A class that allows to configure Mapbox SDKs logging per application.
LogoSettingsInterface
Shows the Mapbox logo on the map.
MapboxHttpService
A service that handles HTTP-related functionality for Mapbox
MapboxMap
Controller for a single MapboxMap instance running on the host platform.
MapboxMapsFlutterMobile
MapboxMapsOptions
Configurations for the external resources that are used by Maps API object, such as maps data directory and base URL.
MapboxOptions
Class for Mapbox SDK settings management
MapInterfaces_PigeonCodec
MapRecorderMessenger_PigeonCodec
MapWidget
A MapWidget provides an embeddable map interface. You use this class to display map information and to manipulate the map contents from your application. You can center the map on a given coordinate, specify the size of the area you want to display, and style the features of the map to fit your application's use case.
OfflineManager
The OfflineManager provides a configuration interface and entrypoint for offline map functionality.
OfflineMessenger_PigeonCodec
OfflineSwitch
Instance that allows connecting or disconnecting the Mapbox stack to the network.
OnSnapshotStyleListener
PerformaceStatistics_PigeonCodec
PointAnnotationManager
The PointAnnotationManager to add/update/delete PointAnnotationAnnotations on the map.
PointAnnotationMessenger_PigeonCodec
PolygonAnnotationManager
The PolygonAnnotationManager to add/update/delete PolygonAnnotationAnnotations on the map.
PolygonAnnotationMessenger_PigeonCodec
PolylineAnnotationManager
The PolylineAnnotationManager to add/update/delete PolylineAnnotationAnnotations on the map.
PolylineAnnotationMessenger_PigeonCodec
Projection
Collection of Spherical Mercator projection methods.
ScaleBarSettingsInterface
Shows the scale bar on the map.
Settings
Settings class provides non-persistent, in-process key-value storage.
Settings_PigeonCodec
Snapshotter
A utility class for capturing styled map snapshots.
SnapshotterMessenger_PigeonCodec
StyleManager
Interface for managing style of the map.
TileStore
TileStore manages downloads and storage for requests to tile-related API endpoints, enforcing a disk usage quota: tiles available on disk may be deleted to make room for a new download. This interface can be used by an app developer to set the disk quota. The rest of TileStore API is intended for native SDK consumption only.
ViewportInternal_PigeonCodec

Enums

DownloadErrorCode
Enum which represents different error cases which could happen during download session.
DownloadState
Enum representing state of download session.
HttpMethod
HTTP defines a set of request methods to indicate the desired action to be performed for a given resource.
HttpRequestErrorType
Enum which describes possible error types which could happen during HTTP request/download calls.
OfflineRegionDownloadState
Describes the download state of a region.
StylePackErrorType
Describes the reason for a style package download request failure.
TileRegionErrorType
Describes the reason for a tile region download request failure.
ViewAnnotationAnchor
Enum describing how to place view annotation relatively to geometry.

Extensions

ScreenBoxToJson on ScreenBox
ScreenCoordinateToJson on ScreenCoordinate

Constants

mapboxPluginVersion → const String
Version of the mapbox_maps_flutter_mobile plugin.
pigeonMethodCodec → const StandardMethodCodec

Functions

wrapResponse({Object? result, PlatformException? error, bool empty = false}) List<Object?>

Typedefs

OnPlatformViewCreatedCallback = void Function(int)