IndoorController class
Pairs the pigeon-generated _IndoorMessenger (selectFloor host API)
with the IndoorState broadcast stream produced by the
MapEventChannel event channel.
- Annotations
-
- @experimental
Constructors
- IndoorController({BinaryMessenger? binaryMessenger, String messageChannelSuffix = ''})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
indoorUpdates
→ Stream<
IndoorState> -
Broadcast stream of the current
IndoorState(available floors and the selected floor) for the venue underneath the camera.no setter - pigeonVar_binaryMessenger → BinaryMessenger?
-
finalinherited
- pigeonVar_messageChannelSuffix → String
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
selectFloor(
String? floorId) → Future< void> -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited